Source

mohitmishra786/low-level-dev-skills

142 skills · 44.7K combined installs

Skills from this source

#
Skill
Source
8W Activity
Installs
1
apple-silicon Apple Silicon skill for M-series development and profiling. Use when leveraging unified memory, Metal Performance Sha…
mohitmishra786/low-level-dev-skills
171
2
adc-dac-baremetal Bare-metal ADC and DAC skill. Use when configuring analog sampling, DMA-driven ADC, calibration, or DAC output on MCU…
mohitmishra786/low-level-dev-skills
170
3
cpu-pipelines-and-hazards CPU pipeline skill for hazards, forwarding, and stalls. Use when explaining pipeline stages, data/control hazards, fo…
mohitmishra786/low-level-dev-skills
170
4
kernel-debugging Linux kernel debugging skill for kgdb, kdb, ftrace, kprobes, and crash analysis. Use when setting up kgdb over serial…
mohitmishra786/low-level-dev-skills
170
5
platform-device-model Platform device model skill for Linux driver binding. Use when implementing platform_driver probe/remove, sysfs attri…
mohitmishra786/low-level-dev-skills
170
6
virtual-memory-paging-and-tlb Virtual memory skill for paging, page tables, and TLB. Use when explaining page faults, multi-level page tables, TLB …
mohitmishra786/low-level-dev-skills
170
7
kernel-testing Linux kernel testing skill for KUnit, kselftest, syzkaller, and LTP. Use when writing KUnit tests, running kselftest …
mohitmishra786/low-level-dev-skills
169
8
protocol-analysis Protocol analysis skill for serial bus debugging. Use when decoding I2C/SPI/UART with logic analyzer concepts, sigrok…
mohitmishra786/low-level-dev-skills
169
9
qemu-embedded-simulation QEMU embedded simulation skill for bare-metal MCU testing. Use when running ARM/RISC-V firmware in QEMU, selecting ma…
mohitmishra786/low-level-dev-skills
169
10
compiler-optimizations-deep Deep compiler optimizations skill for RA, ISel, and PGO. Use when explaining register allocation, instruction selecti…
mohitmishra786/low-level-dev-skills
168
11
kernel-security Linux kernel security skill for LSM, hardening, and exploit mitigations. Use when writing SELinux/AppArmor policies, …
mohitmishra786/low-level-dev-skills
168
12
custom-allocators Custom allocator skill for memory allocation strategies. Use when implementing pool/slab/arena allocators, tuning jem…
mohitmishra786/low-level-dev-skills
167
13
peripherals-from-datasheet Peripheral driver methodology skill from MCU reference manuals. Use when reading register maps, timing diagrams, and …
mohitmishra786/low-level-dev-skills
167
14
cuda-profiling CUDA profiling skill for NVIDIA GPU performance analysis. Use when profiling kernels with Nsight Systems or Nsight Co…
mohitmishra786/low-level-dev-skills
166
15
jit-compilation JIT compilation skill for runtime code generation. Use when building LLVM ORC JIT, LLJIT, Cranelift JIT, inline cache…
mohitmishra786/low-level-dev-skills
166
16
numa-programming NUMA programming skill for multi-socket memory locality. Use when detecting NUMA topology, binding processes with num…
mohitmishra786/low-level-dev-skills
166
17
rdma-verbs RDMA verbs skill for InfiniBand and RoCE programming. Use when using libibverbs API, creating queue pairs, RDMA read/…
mohitmishra786/low-level-dev-skills
166
18
containers-internals Linux containers internals skill for namespaces, cgroups, and OCI. Use when understanding clone/unshare namespaces, c…
mohitmishra786/low-level-dev-skills
165
19
cuda-debugging CUDA debugging skill for GPU program correctness. Use when debugging with cuda-gdb, running NVIDIA Compute Sanitizer …
mohitmishra786/low-level-dev-skills
165
20
dpdk DPDK skill for userspace packet I/O. Use when initializing EAL, configuring PMD drivers, using mbuf pools and rte_rin…
mohitmishra786/low-level-dev-skills
165
21
gpu-memory-model GPU memory model skill for SIMT execution and memory hierarchy. Use when analyzing warp divergence, memory coalescing…
mohitmishra786/low-level-dev-skills
165
22
openmp OpenMP skill for shared-memory parallel programming. Use when writing parallel for loops, reductions, task parallelis…
mohitmishra786/low-level-dev-skills
165
23
compiler-frontend Compiler frontend skill for lexing, parsing, and type checking. Use when building a lexer/parser, designing AST nodes…
mohitmishra786/low-level-dev-skills
164
24
code-generation-and-backends Code generation and backends skill for LLVM targets. Use when explaining instruction selection, DAG legalization, tar…
mohitmishra786/low-level-dev-skills
163
25
os-dev-scratch OS development from scratch skill for bootloader through context switching. Use when building a minimal x86-64 OS, se…
mohitmishra786/low-level-dev-skills
163
26
resource-optimization-lowend Resource optimization skill for constrained embedded targets. Use when reducing flash/RAM usage, analyzing stack dept…
mohitmishra786/low-level-dev-skills
163
27
io-uring io_uring skill for Linux async I/O. Use when building high-performance servers with liburing, multi-shot operations, …
mohitmishra786/low-level-dev-skills
162
28
riscv-privileged RISC-V privileged architecture skill for M/S/U modes and traps. Use when handling CSRs, trap handlers, PLIC/CLINT int…
mohitmishra786/low-level-dev-skills
162
29
timers-pwm-baremetal Bare-metal timer and PWM skill. Use when configuring general-purpose timers for PWM, input capture, or periodic ticks…
mohitmishra786/low-level-dev-skills
162
30
hip-rocm HIP and ROCm skill for AMD GPU programming. Use when writing HIP kernels with hipcc, porting CUDA code via HIPIFY, pr…
mohitmishra786/low-level-dev-skills
161
31
branch-prediction-and-speculation Branch prediction and speculation skill for CPU security and performance. Use when explaining branch predictors, misp…
mohitmishra786/low-level-dev-skills
160
32
hypervisor-internals Hardware virtualization internals skill for Intel VT-x and AMD-V. Use when studying VMCS/VMCB, EPT/NPT page tables, V…
mohitmishra786/low-level-dev-skills
160
33
llvm-ir-and-passes LLVM IR and passes skill for reading compiler IR. Use when analyzing LLVM IR, understanding SSA, pass pipeline order,…
mohitmishra786/low-level-dev-skills
160
34
llvm-passes LLVM passes skill for writing compiler optimizations. Use when writing FunctionPass or ModulePass, registering PassPl…
mohitmishra786/low-level-dev-skills
159
35
af-xdp AF_XDP skill for high-performance XDP sockets. Use when creating AF_XDP sockets, configuring UMEM and XSK rings, XDP_…
mohitmishra786/low-level-dev-skills
158
36
arm-sve ARM SVE skill for scalable vector extension programming. Use when writing SVE intrinsics, predicate registers, VLA lo…
mohitmishra786/low-level-dev-skills
158
37
mlir MLIR skill for multi-level intermediate representation. Use when writing custom dialects, defining ops with ODS, writ…
mohitmishra786/low-level-dev-skills
158
38
mpi MPI skill for distributed-memory parallel programming. Use when writing MPI_Send/Recv programs, collective operations…
mohitmishra786/low-level-dev-skills
158
39
triton-lang Triton language skill for Python GPU kernel authoring. Use when writing Triton kernels with @triton.jit, tl.load/stor…
mohitmishra786/low-level-dev-skills
156
40
verilog-basics-for-lowlevel Verilog basics skill for firmware and kernel engineers. Use when reading RTL to understand hardware behavior, reset/c…
mohitmishra786/low-level-dev-skills
154
41
carbon-lang Carbon language skill for C++ interop and toolchain. Use when evaluating Carbon syntax, bidirectional C++ interop, bu…
mohitmishra786/low-level-dev-skills
149
42
hare-lang Hare language skill for simple systems programming. Use when building with hare build/test/run, Hare stdlib, C FFI wi…
mohitmishra786/low-level-dev-skills
148
Page 3 · 142 total Previous